# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/plot_main.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(1032, 420)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_title = QtWidgets.QHBoxLayout()
        self.horizontalLayout_title.setObjectName("horizontalLayout_title")
        self.verticalLayout.addLayout(self.horizontalLayout_title)
        spacerItem1 = QtWidgets.QSpacerItem(20, 27, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem1)
        self.horizontalLayout_enveloppes = QtWidgets.QHBoxLayout()
        self.horizontalLayout_enveloppes.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_enveloppes.setObjectName("horizontalLayout_enveloppes")
        self.pushButton_addCurve = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_addCurve.sizePolicy().hasHeightForWidth())
        self.pushButton_addCurve.setSizePolicy(sizePolicy)
        self.pushButton_addCurve.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurve.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurve.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_addCurve.setObjectName("pushButton_addCurve")
        self.horizontalLayout_enveloppes.addWidget(self.pushButton_addCurve)
        self.label_enveloppes = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_enveloppes.sizePolicy().hasHeightForWidth())
        self.label_enveloppes.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_enveloppes.setFont(font)
        self.label_enveloppes.setObjectName("label_enveloppes")
        self.horizontalLayout_enveloppes.addWidget(self.label_enveloppes)
        self.line_2 = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line_2.sizePolicy().hasHeightForWidth())
        self.line_2.setSizePolicy(sizePolicy)
        self.line_2.setFrameShape(QtWidgets.QFrame.HLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout_enveloppes.addWidget(self.line_2)
        self.pushButton_killAllCurves = QtWidgets.QPushButton(Form)
        self.pushButton_killAllCurves.setEnabled(True)
        self.pushButton_killAllCurves.setMinimumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllCurves.setMaximumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllCurves.setBaseSize(QtCore.QSize(70, 28))
        self.pushButton_killAllCurves.setObjectName("pushButton_killAllCurves")
        self.horizontalLayout_enveloppes.addWidget(self.pushButton_killAllCurves)
        self.verticalLayout.addLayout(self.horizontalLayout_enveloppes)
        self.tabWidget = QtWidgets.QTabWidget(Form)
        self.tabWidget.setMinimumSize(QtCore.QSize(960, 0))
        self.tabWidget.setAutoFillBackground(True)
        self.tabWidget.setMovable(True)
        self.tabWidget.setObjectName("tabWidget")
        self.tab = QtWidgets.QWidget()
        self.tab.setObjectName("tab")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.tab)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.tabWidget.addTab(self.tab, "")
        self.verticalLayout.addWidget(self.tabWidget)
        self.frame_singleCurve = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame_singleCurve.sizePolicy().hasHeightForWidth())
        self.frame_singleCurve.setSizePolicy(sizePolicy)
        self.frame_singleCurve.setMinimumSize(QtCore.QSize(960, 0))
        self.frame_singleCurve.setBaseSize(QtCore.QSize(0, 10))
        self.frame_singleCurve.setFrameShape(QtWidgets.QFrame.Box)
        self.frame_singleCurve.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.frame_singleCurve.setObjectName("frame_singleCurve")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.frame_singleCurve)
        self.verticalLayout_3.setContentsMargins(1, 1, 1, 1)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.verticalLayout_singleCurve = QtWidgets.QVBoxLayout()
        self.verticalLayout_singleCurve.setObjectName("verticalLayout_singleCurve")
        self.verticalLayout_3.addLayout(self.verticalLayout_singleCurve)
        self.verticalLayout.addWidget(self.frame_singleCurve)
        spacerItem2 = QtWidgets.QSpacerItem(20, 27, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem2)
        self.horizontalLayout_refPoints = QtWidgets.QHBoxLayout()
        self.horizontalLayout_refPoints.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_refPoints.setObjectName("horizontalLayout_refPoints")
        self.pushButton_addRefPoint = QtWidgets.QPushButton(Form)
        self.pushButton_addRefPoint.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_addRefPoint.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_addRefPoint.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_addRefPoint.setObjectName("pushButton_addRefPoint")
        self.horizontalLayout_refPoints.addWidget(self.pushButton_addRefPoint)
        self.label_RefPoints = QtWidgets.QLabel(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_RefPoints.sizePolicy().hasHeightForWidth())
        self.label_RefPoints.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_RefPoints.setFont(font)
        self.label_RefPoints.setObjectName("label_RefPoints")
        self.horizontalLayout_refPoints.addWidget(self.label_RefPoints)
        self.line = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line.sizePolicy().hasHeightForWidth())
        self.line.setSizePolicy(sizePolicy)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_refPoints.addWidget(self.line)
        self.pushButton_openRefPoints = QtWidgets.QPushButton(Form)
        self.pushButton_openRefPoints.setMinimumSize(QtCore.QSize(70, 28))
        self.pushButton_openRefPoints.setMaximumSize(QtCore.QSize(70, 28))
        self.pushButton_openRefPoints.setBaseSize(QtCore.QSize(70, 28))
        self.pushButton_openRefPoints.setObjectName("pushButton_openRefPoints")
        self.horizontalLayout_refPoints.addWidget(self.pushButton_openRefPoints)
        self.pushButton_killAllRefPoints = QtWidgets.QPushButton(Form)
        self.pushButton_killAllRefPoints.setEnabled(False)
        self.pushButton_killAllRefPoints.setMinimumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllRefPoints.setMaximumSize(QtCore.QSize(70, 28))
        self.pushButton_killAllRefPoints.setBaseSize(QtCore.QSize(70, 28))
        self.pushButton_killAllRefPoints.setObjectName("pushButton_killAllRefPoints")
        self.horizontalLayout_refPoints.addWidget(self.pushButton_killAllRefPoints)
        self.verticalLayout.addLayout(self.horizontalLayout_refPoints)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.line_3 = QtWidgets.QFrame(Form)
        self.line_3.setMinimumSize(QtCore.QSize(28, 0))
        self.line_3.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_3.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_3.setObjectName("line_3")
        self.horizontalLayout.addWidget(self.line_3)
        self.verticalLayout_points_settings = QtWidgets.QVBoxLayout()
        self.verticalLayout_points_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_points_settings.setSpacing(6)
        self.verticalLayout_points_settings.setObjectName("verticalLayout_points_settings")
        self.horizontalLayout.addLayout(self.verticalLayout_points_settings)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem3 = QtWidgets.QSpacerItem(20, 13, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem3)
        self.gridLayout_Go = QtWidgets.QGridLayout()
        self.gridLayout_Go.setObjectName("gridLayout_Go")
        self.widget_showParams = QtWidgets.QWidget(Form)
        self.widget_showParams.setObjectName("widget_showParams")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.widget_showParams)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.checkBox_legend = QtWidgets.QCheckBox(self.widget_showParams)
        self.checkBox_legend.setAutoExclusive(False)
        self.checkBox_legend.setObjectName("checkBox_legend")
        self.verticalLayout_5.addWidget(self.checkBox_legend)
        self.checkBox_pointRange = QtWidgets.QCheckBox(self.widget_showParams)
        self.checkBox_pointRange.setChecked(False)
        self.checkBox_pointRange.setObjectName("checkBox_pointRange")
        self.verticalLayout_5.addWidget(self.checkBox_pointRange)
        self.gridLayout_Go.addWidget(self.widget_showParams, 0, 0, 1, 1)
        self.pushButton_plotOne = QtWidgets.QPushButton(Form)
        self.pushButton_plotOne.setMinimumSize(QtCore.QSize(90, 32))
        self.pushButton_plotOne.setMaximumSize(QtCore.QSize(90, 32))
        self.pushButton_plotOne.setBaseSize(QtCore.QSize(90, 32))
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_plotOne.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_plotOne.setIcon(icon)
        self.pushButton_plotOne.setIconSize(QtCore.QSize(24, 24))
        self.pushButton_plotOne.setObjectName("pushButton_plotOne")
        self.gridLayout_Go.addWidget(self.pushButton_plotOne, 0, 1, 1, 1)
        self.widget_dummy = QtWidgets.QWidget(Form)
        self.widget_dummy.setObjectName("widget_dummy")
        self.gridLayout_Go.addWidget(self.widget_dummy, 0, 3, 1, 1)
        self.pushButton_plotAll = QtWidgets.QPushButton(Form)
        self.pushButton_plotAll.setMinimumSize(QtCore.QSize(90, 32))
        self.pushButton_plotAll.setMaximumSize(QtCore.QSize(90, 32))
        self.pushButton_plotAll.setBaseSize(QtCore.QSize(90, 32))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/buttons/button_plotAll.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_plotAll.setIcon(icon1)
        self.pushButton_plotAll.setIconSize(QtCore.QSize(20, 20))
        self.pushButton_plotAll.setObjectName("pushButton_plotAll")
        self.gridLayout_Go.addWidget(self.pushButton_plotAll, 0, 2, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_Go)
        spacerItem4 = QtWidgets.QSpacerItem(20, 43, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.MinimumExpanding)
        self.verticalLayout.addItem(spacerItem4)
        self.horizontalLayout_2.addLayout(self.verticalLayout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem5)

        self.retranslateUi(Form)
        self.tabWidget.setCurrentIndex(0)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.pushButton_addCurve.setToolTip(_translate("Form", "Add a new curve (Ctrl+N)"))
        self.pushButton_addCurve.setText(_translate("Form", "+"))
        self.pushButton_addCurve.setShortcut(_translate("Form", "Ctrl+N"))
        self.label_enveloppes.setText(_translate("Form", "Critical enveloppes"))
        self.pushButton_killAllCurves.setToolTip(_translate("Form", "Delete all curves (Ctrl+Shift+Del)"))
        self.pushButton_killAllCurves.setText(_translate("Form", "Clear all"))
        self.pushButton_killAllCurves.setShortcut(_translate("Form", "Ctrl+Shift+Del"))
        self.pushButton_addRefPoint.setToolTip(_translate("Form", "Add a new reference point (Ctrl+R)"))
        self.pushButton_addRefPoint.setText(_translate("Form", "+"))
        self.pushButton_addRefPoint.setShortcut(_translate("Form", "Ctrl+R"))
        self.label_RefPoints.setText(_translate("Form", "<u>R</u>eference points"))
        self.pushButton_openRefPoints.setToolTip(_translate("Form", "Import reference points from (x, y) data"))
        self.pushButton_openRefPoints.setText(_translate("Form", "Import"))
        self.pushButton_killAllRefPoints.setToolTip(_translate("Form", "Delete all reference points"))
        self.pushButton_killAllRefPoints.setText(_translate("Form", "Clear all"))
        self.checkBox_legend.setToolTip(_translate("Form", "Check to add legend on plot (Alt+L)"))
        self.checkBox_legend.setText(_translate("Form", "show &legend"))
        self.checkBox_pointRange.setToolTip(_translate("Form", "Check to show range as a light gray line under curve points (Alt+P)"))
        self.checkBox_pointRange.setText(_translate("Form", "show curve &point range"))
        self.pushButton_plotOne.setToolTip(_translate("Form", "Plot current curve and reference points (Ctrl+Enter)"))
        self.pushButton_plotOne.setText(_translate("Form", "Plot"))
        self.pushButton_plotOne.setShortcut(_translate("Form", "Ctrl+Return"))
        self.pushButton_plotAll.setToolTip(_translate("Form", "Plot all curves and points (Crtl+Shift+Enter)"))
        self.pushButton_plotAll.setText(_translate("Form", " Plot all"))
        self.pushButton_plotAll.setShortcut(_translate("Form", "Ctrl+Shift+Return"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

