# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/groupBox_fluids.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(194, 101)
        self.horizontalLayout = QtWidgets.QHBoxLayout(Form)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.groupBox_fluids = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_fluids.sizePolicy().hasHeightForWidth())
        self.groupBox_fluids.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_fluids.setFont(font)
        self.groupBox_fluids.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_fluids.setCheckable(True)
        self.groupBox_fluids.setChecked(False)
        self.groupBox_fluids.setObjectName("groupBox_fluids")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_fluids)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_rhosr = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhosr.sizePolicy().hasHeightForWidth())
        self.label_rhosr.setSizePolicy(sizePolicy)
        self.label_rhosr.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhosr.setText("")
        self.label_rhosr.setPixmap(QtGui.QPixmap(":/params/params_rhosr.png"))
        self.label_rhosr.setScaledContents(True)
        self.label_rhosr.setObjectName("label_rhosr")
        self.gridLayout_2.addWidget(self.label_rhosr, 1, 4, 1, 1)
        self.horizontalLayout_rhof = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhof.setSpacing(0)
        self.horizontalLayout_rhof.setObjectName("horizontalLayout_rhof")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhof, 0, 5, 1, 1)
        self.horizontalLayout_lamdaB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaB.setSpacing(0)
        self.horizontalLayout_lamdaB.setObjectName("horizontalLayout_lamdaB")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaB, 0, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_3.setMaximumSize(QtCore.QSize(6, 24))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 0, 1, 1)
        self.horizontalLayout_rhosr = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhosr.setSpacing(0)
        self.horizontalLayout_rhosr.setObjectName("horizontalLayout_rhosr")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhosr, 1, 5, 1, 1)
        self.label_lamdaD = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaD.sizePolicy().hasHeightForWidth())
        self.label_lamdaD.setSizePolicy(sizePolicy)
        self.label_lamdaD.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaD.setText("")
        self.label_lamdaD.setPixmap(QtGui.QPixmap(":/params/params_lamdaD.png"))
        self.label_lamdaD.setScaledContents(True)
        self.label_lamdaD.setObjectName("label_lamdaD")
        self.gridLayout_2.addWidget(self.label_lamdaD, 1, 1, 1, 1)
        self.label_lamdaB = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaB.sizePolicy().hasHeightForWidth())
        self.label_lamdaB.setSizePolicy(sizePolicy)
        self.label_lamdaB.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaB.setPixmap(QtGui.QPixmap(":/params/params_lamdaB.png"))
        self.label_lamdaB.setScaledContents(True)
        self.label_lamdaB.setObjectName("label_lamdaB")
        self.gridLayout_2.addWidget(self.label_lamdaB, 0, 1, 1, 1)
        self.horizontalLayout_lamdaD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaD.setSpacing(0)
        self.horizontalLayout_lamdaD.setObjectName("horizontalLayout_lamdaD")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaD, 1, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_4.setMaximumSize(QtCore.QSize(6, 24))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_rhof = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhof.sizePolicy().hasHeightForWidth())
        self.label_rhof.setSizePolicy(sizePolicy)
        self.label_rhof.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhof.setText("")
        self.label_rhof.setPixmap(QtGui.QPixmap(":/params/params_rhof.png"))
        self.label_rhof.setScaledContents(True)
        self.label_rhof.setObjectName("label_rhof")
        self.gridLayout_2.addWidget(self.label_rhof, 0, 4, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_5.setMaximumSize(QtCore.QSize(12, 24))
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 3, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_6.setMaximumSize(QtCore.QSize(12, 24))
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 3, 1, 1)
        self.horizontalLayout.addWidget(self.groupBox_fluids)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox_fluids.setToolTip(_translate("Form", "Check to activate fluids pore pressure parameters"))
        self.groupBox_fluids.setTitle(_translate("Form", "&Fluids pore pressure"))
        self.label_rhosr.setToolTip(_translate("Form", "Volumetric mass density of saturated rock"))
        self.label_3.setText(_translate("Form", "<sup>5</sup>"))
        self.label_lamdaD.setToolTip(_translate("Form", "Basal fluids overpressure ratio"))
        self.label_lamdaB.setToolTip(_translate("Form", "Bulk fluids overpressure ratio"))
        self.label_4.setText(_translate("Form", "<sup>6</sup>"))
        self.label_rhof.setToolTip(_translate("Form", "Volumetric mass density of fluids"))
        self.label_5.setText(_translate("Form", "<sup>7</sup>"))
        self.label_6.setText(_translate("Form", "<sup>8</sup>"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

