# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '../uis/curve_settings.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        Form.resize(901, 269)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.horizontalLayout_context = QtWidgets.QHBoxLayout()
        self.horizontalLayout_context.setObjectName("horizontalLayout_context")
        self.horizontalLayout_11.addLayout(self.horizontalLayout_context)
        self.groupBox_friction = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_friction.sizePolicy().hasHeightForWidth())
        self.groupBox_friction.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_friction.setFont(font)
        self.groupBox_friction.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_friction.setCheckable(False)
        self.groupBox_friction.setChecked(False)
        self.groupBox_friction.setObjectName("groupBox_friction")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_friction)
        self.gridLayout.setObjectName("gridLayout")
        self.label_phiD = QtWidgets.QLabel(self.groupBox_friction)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_phiD.sizePolicy().hasHeightForWidth())
        self.label_phiD.setSizePolicy(sizePolicy)
        self.label_phiD.setMaximumSize(QtCore.QSize(20, 24))
        self.label_phiD.setPixmap(QtGui.QPixmap(":/params/params_phiD.png"))
        self.label_phiD.setScaledContents(True)
        self.label_phiD.setObjectName("label_phiD")
        self.gridLayout.addWidget(self.label_phiD, 1, 1, 1, 1)
        self.label_phiB = QtWidgets.QLabel(self.groupBox_friction)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_phiB.sizePolicy().hasHeightForWidth())
        self.label_phiB.setSizePolicy(sizePolicy)
        self.label_phiB.setMaximumSize(QtCore.QSize(20, 24))
        self.label_phiB.setText("")
        self.label_phiB.setPixmap(QtGui.QPixmap(":/params/params_phiB.png"))
        self.label_phiB.setScaledContents(True)
        self.label_phiB.setObjectName("label_phiB")
        self.gridLayout.addWidget(self.label_phiB, 0, 1, 1, 1)
        self.horizontalLayout_phiD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_phiD.setSpacing(0)
        self.horizontalLayout_phiD.setObjectName("horizontalLayout_phiD")
        self.gridLayout.addLayout(self.horizontalLayout_phiD, 1, 2, 1, 1)
        self.horizontalLayout_phiB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_phiB.setSpacing(0)
        self.horizontalLayout_phiB.setObjectName("horizontalLayout_phiB")
        self.gridLayout.addLayout(self.horizontalLayout_phiB, 0, 2, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_friction)
        self.label.setMaximumSize(QtCore.QSize(6, 24))
        self.label.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label.setObjectName("label")
        self.gridLayout.addWidget(self.label, 0, 0, 1, 1)
        self.label_2 = QtWidgets.QLabel(self.groupBox_friction)
        self.label_2.setMaximumSize(QtCore.QSize(6, 24))
        self.label_2.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_2.setObjectName("label_2")
        self.gridLayout.addWidget(self.label_2, 1, 0, 1, 1)
        self.horizontalLayout_11.addWidget(self.groupBox_friction)
        self.groupBox_fluids = QtWidgets.QGroupBox(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_fluids.sizePolicy().hasHeightForWidth())
        self.groupBox_fluids.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.groupBox_fluids.setFont(font)
        self.groupBox_fluids.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.groupBox_fluids.setCheckable(True)
        self.groupBox_fluids.setChecked(False)
        self.groupBox_fluids.setObjectName("groupBox_fluids")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_fluids)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.label_rhosr = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhosr.sizePolicy().hasHeightForWidth())
        self.label_rhosr.setSizePolicy(sizePolicy)
        self.label_rhosr.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhosr.setText("")
        self.label_rhosr.setPixmap(QtGui.QPixmap(":/params/params_rhosr.png"))
        self.label_rhosr.setScaledContents(True)
        self.label_rhosr.setObjectName("label_rhosr")
        self.gridLayout_2.addWidget(self.label_rhosr, 1, 4, 1, 1)
        self.horizontalLayout_rhof = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhof.setSpacing(0)
        self.horizontalLayout_rhof.setObjectName("horizontalLayout_rhof")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhof, 0, 5, 1, 1)
        self.horizontalLayout_lamdaB = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaB.setSpacing(0)
        self.horizontalLayout_lamdaB.setObjectName("horizontalLayout_lamdaB")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaB, 0, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_3.setMaximumSize(QtCore.QSize(6, 24))
        self.label_3.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_3.setObjectName("label_3")
        self.gridLayout_2.addWidget(self.label_3, 0, 0, 1, 1)
        self.horizontalLayout_rhosr = QtWidgets.QHBoxLayout()
        self.horizontalLayout_rhosr.setSpacing(0)
        self.horizontalLayout_rhosr.setObjectName("horizontalLayout_rhosr")
        self.gridLayout_2.addLayout(self.horizontalLayout_rhosr, 1, 5, 1, 1)
        self.label_lamdaD = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaD.sizePolicy().hasHeightForWidth())
        self.label_lamdaD.setSizePolicy(sizePolicy)
        self.label_lamdaD.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaD.setText("")
        self.label_lamdaD.setPixmap(QtGui.QPixmap(":/params/params_lamdaD.png"))
        self.label_lamdaD.setScaledContents(True)
        self.label_lamdaD.setObjectName("label_lamdaD")
        self.gridLayout_2.addWidget(self.label_lamdaD, 1, 1, 1, 1)
        self.label_lamdaB = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_lamdaB.sizePolicy().hasHeightForWidth())
        self.label_lamdaB.setSizePolicy(sizePolicy)
        self.label_lamdaB.setMaximumSize(QtCore.QSize(30, 24))
        self.label_lamdaB.setPixmap(QtGui.QPixmap(":/params/params_lamdaB.png"))
        self.label_lamdaB.setScaledContents(True)
        self.label_lamdaB.setObjectName("label_lamdaB")
        self.gridLayout_2.addWidget(self.label_lamdaB, 0, 1, 1, 1)
        self.horizontalLayout_lamdaD = QtWidgets.QHBoxLayout()
        self.horizontalLayout_lamdaD.setSpacing(0)
        self.horizontalLayout_lamdaD.setObjectName("horizontalLayout_lamdaD")
        self.gridLayout_2.addLayout(self.horizontalLayout_lamdaD, 1, 2, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_4.setMaximumSize(QtCore.QSize(6, 24))
        self.label_4.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_4.setObjectName("label_4")
        self.gridLayout_2.addWidget(self.label_4, 1, 0, 1, 1)
        self.label_rhof = QtWidgets.QLabel(self.groupBox_fluids)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_rhof.sizePolicy().hasHeightForWidth())
        self.label_rhof.setSizePolicy(sizePolicy)
        self.label_rhof.setMaximumSize(QtCore.QSize(24, 24))
        self.label_rhof.setText("")
        self.label_rhof.setPixmap(QtGui.QPixmap(":/params/params_rhof.png"))
        self.label_rhof.setScaledContents(True)
        self.label_rhof.setObjectName("label_rhof")
        self.gridLayout_2.addWidget(self.label_rhof, 0, 4, 1, 1)
        self.label_5 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_5.setMinimumSize(QtCore.QSize(12, 0))
        self.label_5.setMaximumSize(QtCore.QSize(12, 24))
        self.label_5.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_5.setObjectName("label_5")
        self.gridLayout_2.addWidget(self.label_5, 0, 3, 1, 1)
        self.label_6 = QtWidgets.QLabel(self.groupBox_fluids)
        self.label_6.setMinimumSize(QtCore.QSize(12, 0))
        self.label_6.setMaximumSize(QtCore.QSize(12, 24))
        self.label_6.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.label_6.setObjectName("label_6")
        self.gridLayout_2.addWidget(self.label_6, 1, 3, 1, 1)
        self.horizontalLayout_11.addWidget(self.groupBox_fluids)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_11.addItem(spacerItem)
        self.dummyVerticalLayout = QtWidgets.QVBoxLayout()
        self.dummyVerticalLayout.setObjectName("dummyVerticalLayout")
        self.pushButton_kill = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_kill.sizePolicy().hasHeightForWidth())
        self.pushButton_kill.setSizePolicy(sizePolicy)
        self.pushButton_kill.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_kill.setText("")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/buttons/button_close.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.pushButton_kill.setIcon(icon)
        self.pushButton_kill.setObjectName("pushButton_kill")
        self.dummyVerticalLayout.addWidget(self.pushButton_kill)
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.dummyVerticalLayout.addItem(spacerItem1)
        self.horizontalLayout_11.addLayout(self.dummyVerticalLayout)
        self.verticalLayout.addLayout(self.horizontalLayout_11)
        self.horizontalLayout_curve = QtWidgets.QHBoxLayout()
        self.horizontalLayout_curve.setObjectName("horizontalLayout_curve")
        self.checkBox_splittedCurves = QtWidgets.QCheckBox(Form)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.checkBox_splittedCurves.setFont(font)
        self.checkBox_splittedCurves.setObjectName("checkBox_splittedCurves")
        self.horizontalLayout_curve.addWidget(self.checkBox_splittedCurves)
        self.checkBox_reverseColormap = QtWidgets.QCheckBox(Form)
        self.checkBox_reverseColormap.setEnabled(False)
        self.checkBox_reverseColormap.setObjectName("checkBox_reverseColormap")
        self.horizontalLayout_curve.addWidget(self.checkBox_reverseColormap)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_curve.addItem(spacerItem2)
        self.verticalLayout.addLayout(self.horizontalLayout_curve)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.verticalLayout_settings = QtWidgets.QVBoxLayout()
        self.verticalLayout_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_settings.setSpacing(0)
        self.verticalLayout_settings.setObjectName("verticalLayout_settings")
        self.horizontalLayout_6.addLayout(self.verticalLayout_settings)
        self.horizontalLayout_label = QtWidgets.QHBoxLayout()
        self.horizontalLayout_label.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_label.setObjectName("horizontalLayout_label")
        self.horizontalLayout_6.addLayout(self.horizontalLayout_label)
        spacerItem3 = QtWidgets.QSpacerItem(150, 20, QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem3)
        self.verticalLayout.addLayout(self.horizontalLayout_6)
        spacerItem4 = QtWidgets.QSpacerItem(20, 25, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout.addItem(spacerItem4)
        self.horizontalLayout_curvepoints = QtWidgets.QHBoxLayout()
        self.horizontalLayout_curvepoints.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.horizontalLayout_curvepoints.setObjectName("horizontalLayout_curvepoints")
        self.pushButton_addCurvePoint = QtWidgets.QPushButton(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton_addCurvePoint.sizePolicy().hasHeightForWidth())
        self.pushButton_addCurvePoint.setSizePolicy(sizePolicy)
        self.pushButton_addCurvePoint.setMinimumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurvePoint.setMaximumSize(QtCore.QSize(28, 28))
        self.pushButton_addCurvePoint.setBaseSize(QtCore.QSize(28, 28))
        self.pushButton_addCurvePoint.setObjectName("pushButton_addCurvePoint")
        self.horizontalLayout_curvepoints.addWidget(self.pushButton_addCurvePoint)
        self.label_CurvePoint = QtWidgets.QLabel(Form)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_CurvePoint.setFont(font)
        self.label_CurvePoint.setObjectName("label_CurvePoint")
        self.horizontalLayout_curvepoints.addWidget(self.label_CurvePoint)
        self.line = QtWidgets.QFrame(Form)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.line.sizePolicy().hasHeightForWidth())
        self.line.setSizePolicy(sizePolicy)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName("line")
        self.horizontalLayout_curvepoints.addWidget(self.line)
        self.pushButton_killAllCurvePoints = QtWidgets.QPushButton(Form)
        self.pushButton_killAllCurvePoints.setEnabled(False)
        self.pushButton_killAllCurvePoints.setMaximumSize(QtCore.QSize(70, 16777215))
        self.pushButton_killAllCurvePoints.setObjectName("pushButton_killAllCurvePoints")
        self.horizontalLayout_curvepoints.addWidget(self.pushButton_killAllCurvePoints)
        self.verticalLayout.addLayout(self.horizontalLayout_curvepoints)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setSpacing(6)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.line_2 = QtWidgets.QFrame(Form)
        self.line_2.setMinimumSize(QtCore.QSize(28, 0))
        self.line_2.setBaseSize(QtCore.QSize(50, 0))
        self.line_2.setFrameShape(QtWidgets.QFrame.VLine)
        self.line_2.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line_2.setObjectName("line_2")
        self.horizontalLayout.addWidget(self.line_2)
        self.verticalLayout_points_settings = QtWidgets.QVBoxLayout()
        self.verticalLayout_points_settings.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.verticalLayout_points_settings.setSpacing(6)
        self.verticalLayout_points_settings.setObjectName("verticalLayout_points_settings")
        self.horizontalLayout.addLayout(self.verticalLayout_points_settings)
        self.verticalLayout.addLayout(self.horizontalLayout)
        spacerItem5 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem5)

        self.retranslateUi(Form)
        self.pushButton_kill.clicked.connect(Form.close)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(_translate("Form", "Form"))
        self.groupBox_friction.setTitle(_translate("Form", "Frictional parameters"))
        self.label_phiD.setToolTip(_translate("Form", "Basal friction angle [deg]"))
        self.label_phiB.setToolTip(_translate("Form", "Bulk friction angle [deg]"))
        self.label.setText(_translate("Form", "<sup>3</sup>"))
        self.label_2.setText(_translate("Form", "<sup>4</sup>"))
        self.groupBox_fluids.setToolTip(_translate("Form", "Check to activate fluids pore pressure parameters (Alt+F)"))
        self.groupBox_fluids.setTitle(_translate("Form", "&Fluids pore pressure"))
        self.label_rhosr.setToolTip(_translate("Form", "Volumetric mass density of saturated rock"))
        self.label_3.setText(_translate("Form", "<sup>5</sup>"))
        self.label_lamdaD.setToolTip(_translate("Form", "Basal fluids overpressure ratio"))
        self.label_lamdaB.setToolTip(_translate("Form", "Bulk fluids overpressure ratio"))
        self.label_4.setText(_translate("Form", "<sup>6</sup>"))
        self.label_rhof.setToolTip(_translate("Form", "Volumetric mass density of fluids"))
        self.label_5.setText(_translate("Form", "<sup>7</sup>"))
        self.label_6.setText(_translate("Form", "<sup>8</sup>"))
        self.pushButton_kill.setToolTip(_translate("Form", "Delete this curve (Ctrl+Del)"))
        self.pushButton_kill.setShortcut(_translate("Form", "Ctrl+Del"))
        self.checkBox_splittedCurves.setToolTip(_translate("Form", "Check to draw with separate settings normal and inverse faulting mechanisms (Alt+D)"))
        self.checkBox_splittedCurves.setText(_translate("Form", "&Distinguish mechanisms"))
        self.checkBox_reverseColormap.setToolTip(_translate("Form", "Check to reverse  (Alt+V)"))
        self.checkBox_reverseColormap.setText(_translate("Form", "Re&verse colormap"))
        self.pushButton_addCurvePoint.setToolTip(_translate("Form", "Add a new point on current curve (Ctrl+P)"))
        self.pushButton_addCurvePoint.setText(_translate("Form", "+"))
        self.pushButton_addCurvePoint.setShortcut(_translate("Form", "Ctrl+P"))
        self.label_CurvePoint.setText(_translate("Form", "<u>P</u>oints on this curve"))
        self.pushButton_killAllCurvePoints.setToolTip(_translate("Form", "Delete all points on current curve"))
        self.pushButton_killAllCurvePoints.setText(_translate("Form", "Clear all"))

import eccw_gui.images.ressources_rc

if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

